@@ -1,4 +1,4 @@
-# $Id: DBILogin.pm,v 1.2 1997/08/30 19:03:49 jdg117 Exp $
+# $Id: DBILogin.pm,v 1.3 1997/10/16 18:39:54 jdg117 Exp $
 package Apache::DBILogin;
 use strict;
 use Apache();
@@ -7,14 +7,13 @@ use DBI;
 use HTTPD::UserAdmin();
 use vars qw($VERSION);
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 my(%Config) = (
     'Auth_DBI_data_source' => '',
 );
 my $prefix = "Apache::DBILogin";
 
 sub handler {
-#print STDERR "Apache::DBILogin--GATEWAY_INTERFACE=$ENV{GATEWAY_INTERFACE}\n";
     my($r) = @_;
     my($key,$val);
     my $attr = {
@@ -38,8 +37,6 @@ sub check {
 
     my $user = $r->connection->user;
 
-#print STDERR $user,"\t",$sent_pwd,"\t",$attr->{data_source},"\n";
-
     unless ( $attr->{data_source} ) {
         $r->log_reason("$prefix is missing the source parameter for database connect", $r->uri);
         return SERVER_ERROR;
@@ -69,39 +66,30 @@ See the access.conf file and the documentation for Apache::AuthenDBI
 
 =head1 DESCRIPTION
 
-=pod
-
-<Directory /opt/www/root>
-
-AuthName MyAuth
-
-AuthType Basic
-
-PerlHandler Apache::Registry::handler
-
-PerlAuthenHandler Apache::DBILogin::handler
-
-SetHandler perl-script
+ #in access.conf
+ <Directory /opt/www/root>
+ AuthName MyAuth
+ AuthType Basic
+ PerlHandler Apache::Registry::handler
+ PerlAuthenHandler Apache::DBILogin::handler
+ SetHandler perl-script
  
-PerlSetVar Auth_DBI_data_source dbi:Oracle:SQLNetAlias
-
-Options Indexes FollowSymLinks ExecCGI
-
-AllowOverride All
+ PerlSetVar Auth_DBI_data_source dbi:Oracle:SQLNetAlias
  
-<Limit GET POST>
+ Options Indexes FollowSymLinks ExecCGI
+ AllowOverride All
+  
+ <Limit GET POST>
+ allow from all
+ require valid-user
+ satisfy all
+ </Limit>
+ </Directory>
 
-allow from all
+=head1 ENVIRONMENT
 
-require valid-user
-
-satisfy all
-
-</Limit>
-
-</Directory>
-
-=cut
+Applications may access the clear text password via the environment
+variable B<HTTP_MODPERL_PASSWORD>
 
 =head1 SEE ALSO
 
